import 'dart:io';

import 'package:flutter/material.dart';
import 'package:foundation_fluttify/foundation_fluttify.dart';
import 'package:netease_live_fluttify/src/android/android.export.g.dart';

import 'netease_view_controller.dart';

/// controller只能是com_tencent_rtmp_ui_TXCloudVideoView或UIView类型
typedef Future<void> OnNeteaseViewCreated(NeteaseViewController controller);

class NeteaseView extends StatefulWidget {
  const NeteaseView({
    Key key,
    this.onNeteaseViewCreated,
  }) : super(key: key);

  /// widget创建完成回调
  final OnNeteaseViewCreated onNeteaseViewCreated;

  @override
  _NeteaseViewState createState() => _NeteaseViewState();
}

class _NeteaseViewState extends State<NeteaseView> {
  NeteaseViewController _controller;

  @override
  Widget build(BuildContext context) {
    if (Platform.isAndroid) {
      return com_netease_vcloud_video_render_NeteaseView_Android(
        onViewCreated: (controller) async {
          _controller = NeteaseViewController.android(controller);
          if (widget.onNeteaseViewCreated != null) {
            widget.onNeteaseViewCreated(_controller);
          }
        },
      );
    } else if (Platform.isIOS) {
      return UIViewWidget(
        onUIViewCreated: (controller) async {
          _controller = NeteaseViewController.ios(controller);
          if (widget.onNeteaseViewCreated != null) {
            widget.onNeteaseViewCreated(_controller);
          }
        },
      );
    } else {
      return Center(
        child: Text('未实现的平台'),
      );
    }
  }

  @override
  void dispose() {
    super.dispose();
  }
}
